@@ -40,10 +40,13 @@ def pearson(x, y, st='i...j, k...j->ik...'):
 
 
 def erpac(pha, amp):
-    """Correlation coefficient between a circular and a linear random variable.
+    """Event-Related Phase Amplitude Coupling.
 
-    Adapted from the function circ_corrcc Circular Statistics Toolbox for
-    Matlab By Philipp Berens, 2009.
+    This function computed the correlation coefficient between a circular and a
+    linear random variable at each time point and across trials. Adapted from
+    the function circ_corrcc Circular Statistics Toolbox for
+    Matlab By Philipp Berens, 2009 :cite:`berens2009circstat`. This function is
+    an adaptation of Voytek, 2013 :cite:`voytek2013method` for tensors.
 
     Parameters
     ----------
@@ -60,8 +63,7 @@ def erpac(pha, amp):
 
     References
     ----------
-    Voytek B, D’Esposito M, Crone N, Knight RT (2013) A method for
-    event-related phase/amplitude coupling. NeuroImage 64:416–424.
+    Voytek et al. 2013 :cite:`voytek2013method`
     """
     # Compute correlation coefficient for sin and cos independently
     n = pha.shape[-1]
@@ -81,7 +83,7 @@ def erpac(pha, amp):
 
 
 def ergcpac(pha, amp, smooth=None, n_jobs=-1):
-    """Event Related PAC computed using the Gaussian Copula Mutual Information.
+    """Event Related PAC using the Gaussian Copula Mutual Information.
 
     This function assumes that phases and amplitudes have already been
     prepared i.e. phases should be represented in a unit circle
@@ -101,10 +103,7 @@ def ergcpac(pha, amp, smooth=None, n_jobs=-1):
 
     References
     ----------
-    Ince RAA, Giordano BL, Kayser C, Rousselet GA, Gross J, Schyns PG (2017) A
-    statistical framework for neuroimaging data analysis based on mutual
-    information estimated via a gaussian copula: Gaussian Copula Mutual
-    Information. Human Brain Mapping 38:1541–1573.
+    Ince et al. 2017 :cite:`ince2017statistical`
     """
     # get shapes
     (n_pha, n_times, _, n_epochs), n_amp = pha.shape, amp.shape[0]  # noqa
