@@ -2,87 +2,11 @@
 import numpy as np
 from scipy.special import erfinv
 
-from functools import partial
-
 from tensorpac.gcmi import nd_mi_gg
 
 
-def pacstr(idpac):
-    """Return correspond methods string."""
-    # Pac methods :
-    if idpac[0] == 1:
-        method = 'Mean Vector Length (MVL, Canolty et al. 2006)'
-    elif idpac[0] == 2:
-        method = 'Kullback-Leiber Distance (KLD, Tort et al. 2010)'
-    elif idpac[0] == 3:
-        method = 'Heights ratio (HR, Lakatos et al. 2005)'
-    elif idpac[0] == 4:
-        method = 'ndPac (Ozkurt et al. 2012)'
-    elif idpac[0] == 5:
-        method = 'Phase-Synchrony (Cohen et al. 2008; Penny et al. 2008)'
-    elif idpac[0] == 6:
-        method = 'Gaussian Copula PAC (Ince et al. 2017)'
-    else:
-        raise ValueError("No corresponding pac method.")
-
-    # Surrogate method :
-    if idpac[1] == 0:
-        suro = 'No surrogates'
-    elif idpac[1] == 1:
-        suro = 'Permute phase across trials (Tort et al. 2010)'
-    elif idpac[1] == 2:
-        suro = 'Swap amplitude time blocks (Bahramisharif et al. 2013)'
-    elif idpac[1] == 3:
-        suro = 'Time lag (Canolty et al. 2006)'
-    else:
-        raise ValueError("No corresponding surrogate method.")
-
-    # Normalization methods :
-    if idpac[2] == 0:
-        norm = 'No normalization'
-    elif idpac[2] == 1:
-        norm = 'Substract the mean of surrogates'
-    elif idpac[2] == 2:
-        norm = 'Divide by the mean of surrogates'
-    elif idpac[2] == 3:
-        norm = 'Substract then divide by the mean of surrogates'
-    elif idpac[2] == 4:
-        norm = "Substract the mean and divide by the deviation of the " + \
-               "surrogates"
-    else:
-        raise ValueError("No corresponding normalization method.")
-
-    return method, suro, norm
-
-
-###############################################################################
-###############################################################################
-#                                   PAC
-###############################################################################
-###############################################################################
-
-
-def get_pac_fcn(idp, n_bins, p):
-    """Get the function for computing Phase-Amplitude coupling."""
-    if idp == 1:  # Mean Vector Length (Canolty, 2006)
-        return partial(mvl)
-    elif idp == 2:  # Kullback-Leiber distance (Tort, 2010)
-        return partial(kld, n_bins=n_bins)
-    elif idp == 3:  # Heights ratio (Lakatos, 2005)
-        return partial(hr, n_bins=n_bins)
-    elif idp == 4:  # ndPac (Ozkurt, 2012)
-        return partial(ndpac, p=p)
-    elif idp == 5:  # Phase-Synchrony (Penny, 2008; Cohen, 2008)
-        return partial(ps)
-    elif idp == 6:  # Gaussian-Copula
-        return partial(gcpac)
-    else:
-        raise ValueError(str(idp) + " is not recognized as a valid pac "
-                         "method.")
-
-
-def mvl(pha, amp):
-    """Mean Vector Length.
+def mean_vector_length(pha, amp):
+    """Tensor-based Mean Vector Length (MVL).
 
     Parameters
     ----------
@@ -97,15 +21,18 @@ def mvl(pha, amp):
 
     References
     ----------
-    Canolty RT (2006) High Gamma Power Is Phase-Locked to Theta. science
-    1128115:313.
+    Canolty et al. 2006 :cite:`canolty2006high`
     """
     return np.abs(np.einsum('i...j, k...j->ik...', amp,
                             np.exp(1j * pha))) / pha.shape[-1]
 
 
-def kld(pha, amp, n_bins=18):
-    """Kullback Leibler Distance.
+def modulation_index(pha, amp, n_bins=18):
+    """Tensor-based Modulation index (MI).
+
+    The modulation index is obtained using the Kullback Leibler Distance which
+    measures how much the distribution of binned amplitude differs from a
+    uniform distribution.
 
     Parameters
     ----------
@@ -122,9 +49,7 @@ def kld(pha, amp, n_bins=18):
 
     References
     ----------
-    Tort ABL, Komorowski R, Eichenbaum H, Kopell N (2010) Measuring
-    Phase-Amplitude Coupling Between Neuronal Oscillations of Different
-    Frequencies. Journal of Neurophysiology 104:1195–1210.
+    Tort et al. 2010 :cite:`tort2010measuring`
     """
     # Get the phase locked binarized amplitude :
     p_j = _kl_hr(pha, amp, n_bins)
@@ -139,8 +64,8 @@ def kld(pha, amp, n_bins=18):
     return pac
 
 
-def hr(pha, amp, n_bins=18):
-    """Heights ratio.
+def heights_ratio(pha, amp, n_bins=18):
+    """Tensor-based Heights ratio (HR).
 
     Parameters
     ----------
@@ -157,9 +82,7 @@ def hr(pha, amp, n_bins=18):
 
     References
     ----------
-    Lakatos P (2005) An Oscillatory Hierarchy Controlling Neuronal
-    Excitability and Stimulus Processing in the Auditory Cortex. Journal of
-    Neurophysiology 94:1904–1911.
+    Lakatos et al. 2005 :cite:`lakatos2005oscillatory`
     """
     # Get the phase locked binarized amplitude :
     p_j = _kl_hr(pha, amp, n_bins)
@@ -193,8 +116,8 @@ def _kl_hr(pha, amp, n_bins, mean_bins=True):
     return np.array(abin)
 
 
-def ndpac(pha, amp, p=.05):
-    """Normalized direct Pac.
+def norm_direct_pac(pha, amp, p=.05):
+    """Tensor-based Normalized direct Pac (ndPAC).
 
     Parameters
     ----------
@@ -213,36 +136,34 @@ def ndpac(pha, amp, p=.05):
 
     References
     ----------
-    Ozkurt TE (2012) Statistically Reliable and Fast Direct Estimation of
-    Phase-Amplitude Cross-Frequency Coupling. Biomedical Engineering, IEEE
-    Transactions on 59:1943–1950.
+    Ozkurt et al. :cite:`ozkurt2012statistically`
     """
-    npts = amp.shape[-1]
-    # Normalize amplitude :
-    # Use the sample standard deviation, as in original Matlab code from author
+    n_times = amp.shape[-1]
+    # normalize amplitude
+    # use the sample standard deviation, as in original matlab code from author
     amp = np.subtract(amp, np.mean(amp, axis=-1, keepdims=True))
     amp = np.divide(amp, np.std(amp, ddof=1, axis=-1, keepdims=True))
-    # Compute pac :
+    # compute pac
     pac = np.abs(np.einsum('i...j, k...j->ik...', amp, np.exp(1j * pha)))
 
+    # no thresholding
     if p == 1. or p is None:
-        # No thresholding
-        return pac / npts
+        return pac / n_times
 
-    s = pac**2
-    pac /= npts
-    # Set to zero non-significant values:
-    xlim = npts * erfinv(1 - p)**2
+    s = pac ** 2
+    pac /= n_times
+    # set to zero non-significant values
+    xlim = n_times * erfinv(1 - p) ** 2
     pac[s <= 2 * xlim] = 0.
     return pac
 
 
-def ps(pha, pha_amp):
-    """Phase Synchrony (Penny, 2008; Cohen, 2008).
+def phase_locking_value(pha, pha_amp):
+    """Tensor-based Phase Locking-Value (PLV).
 
-    In order to measure the phase synchrony, the phase of the amplitude of the
-    higher-frequency signal must be provided, and not the amplitude as in most
-    other PAC functions.
+    In order to measure the phase locking value, the phase of the amplitude of
+    the higher-frequency signal must be provided, and not the amplitude as in
+    most other PAC functions.
 
     Parameters
     ----------
@@ -258,19 +179,16 @@ def ps(pha, pha_amp):
 
     References
     ----------
-    Penny WD, Duzel E, Miller KJ, Ojemann JG (2008) Testing for nested
-    oscillation. Journal of Neuroscience Methods 174:50–61.
-    Cohen MX, Elger CE, Fell J (2008) Oscillatory activity and phase amplitude
-    coupling in the human medial frontal cortex during decision making. Journal
-    of cognitive neuroscience 21:390–402.
+    Penny et al. 2008 :cite:`penny2008testing`, Lachaux et al. 1999
+    :cite:`lachaux1999measuring`
     """
     pac = np.einsum('i...j, k...j->ik...', np.exp(-1j * pha_amp),
                     np.exp(1j * pha))
     return np.abs(pac) / pha.shape[-1]
 
 
-def gcpac(pha, amp):
-    """Gaussian Copula Phase-amplitude coupling.
+def gauss_cop_pac(pha, amp):
+    """Tensor-based Gaussian Copula PAC (gcPac).
 
     This function assumes that phases and amplitudes have already been
     prepared i.e. phases should be represented in a unit circle
@@ -290,10 +208,7 @@ def gcpac(pha, amp):
 
     References
     ----------
-    Ince RAA, Giordano BL, Kayser C, Rousselet GA, Gross J, Schyns PG (2017) A
-    statistical framework for neuroimaging data analysis based on mutual
-    information estimated via a gaussian copula: Gaussian Copula Mutual
-    Information. Human Brain Mapping 38:1541–1573.
+    Ince et al 2017. :cite:`ince2017statistical`
     """
     # prepare the shape of gcpac
     n_pha, n_amp = pha.shape[0], amp.shape[0]
